==> darwin-shared-0.2.37.tar.gz: darwin-shared-0.2.37/darwin/utils/apiMessage.py <==
# coding: utf-8

from ..utils.language import Language


class ApiMessage(object):

    def __init__(self, messages):
        self.messages = messages

    def __add__(self, other):
        messages = {}
        for key in self.messages.keys():
            value = self.messages[key]
            value.update(other.messages[key])
            messages[key] = value
        return ApiMessage(messages)

    def __radd__(self, other):
        if other == 0:
            return self
        else:
            return self.__add__(other)

    def __str__(self):
        return self.messages.__str__()

    def get(self, key, language, **data):
        data["index"] = "Element %s: " % data.get("index") if "index" in data else ""
        return self.messages.get(language, {}).get(key, "NULL").format(**data)


class SharedApiCode:

    invalidAction = "invalidAction"
    invalidIds = "invalidIds"
    invalidJson = "invalidJson"
    invalidToken = "invalidToken"
    invalidExternalId = "invalidExternalId"
    invalidAmount = "invalidAmount"
    invalidDate = "invalidDate"
    invalidPermission = "invalidPermission"
    invalidTaxId = "invalidTaxId"
    invalidName = "invalidName"
    invalidEmail = "invalidEmail"
    invalidPhone = "invalidPhone"
    invalidAddress = "invalidAddress"
    invalidStreetLine1 = "invalidStreetLine1"
    invalidStreetLine2 = "invalidStreetLine2"
    invalidDistrict = "invalidDistrict"
    invalidCity = "invalidCity"
    invalidStateCode = "invalidStateCode"
    invalidZipCode = "invalidZipCode"
    invalidTags = "invalidTags"
    invalidCsv = "invalidCsv"
    invalidStatus = "invalidStatus"
    invalidDescription = "invalidDescription"
    invalidDigitalSignature = "invalidDigitalSignature"
    invalidLimit = "invalidLimit"


class SharedApiMessageKey:

    usedParameter = "usedParameter"
    objectNotFound = "objectNotFound"
    objectNotAllowed = "objectNotAllowed"
    objectNotMatchKeys = "objectNotMatchKeys"
    missingParameter = "missingParameter"
    invalidParameter = "invalidParameter"
    multipleErrors = "multipleErrors"
    emptyString = "emptyString"
    shortString = "shortString"
    longString = "longString"
    notString = "notString"
    notArray = "notArray"
    notDictionary = "notDictionary"
    notInteger = "notInteger"
    notMatchRegex = "notMatchRegex"
    emptyArray = "emptyArray"
    positiveInteger = "positiveInteger"
    nonNegativeInteger = "nonNegativeInteger"
    integerGreaterThanMax = "integerGreaterThanMax"
    lengthGreaterThanMax = "lengthGreaterThanMax"
    invalidDateOrder = "invalidDateOrder"
    invalidCpf = "invalidCpf"
    invalidCnpj = "invalidCnpj"
    invalidTaxId = "invalidTaxId"
    invalidZipCode = "invalidZipCode"
    invalidStateCode = "invalidStateCode"
    greaterThanToday = "greaterThanToday"
    greaterThanOrEqualToToday = "greaterThanOrEqualToToday"
    invalidHeaders = "invalidHeaders"
    invalidColumn = "invalidColumn"
    invalidEmail = "invalidEmail"
    emailSent = "emailSent"
    checkApiDoc = "checkApiDoc"
    tokenWaitToRequest = "tokenWaitToRequest"
    tokenInvalid = "tokenInvalid"
    permissionInvalid = "permissionInvalid"
    permissionAdmin = "permissionAdmin"
    permissionAdminOrFinancial = "permissionAdminOrFinancial"
    deletedEntity = "deletedEntity"
    invalidDigitalSignature = "notMatchSignature"


SharedApiMessage = ApiMessage(
    messages={
        Language.english: {
            SharedApiMessageKey.usedParameter:               "This \"{parameter}\" has already been used, you should use another one.",
            SharedApiMessageKey.objectNotFound:              "{index}{object} not found.",
            SharedApiMessageKey.objectNotAllowed:            "You are not allowed to access this object.",
            SharedApiMessageKey.objectNotMatchKeys:          "{index}Your object does not match all required keys.",
            SharedApiMessageKey.missingParameter:            "{index}Missing \"{parameter}\" parameter.",
            SharedApiMessageKey.invalidParameter:            "{index}\"{parameter}\" is not valid.",
            SharedApiMessageKey.multipleErrors:              "Your array contains invalid elements.",
            SharedApiMessageKey.shortString:                 "{index}\"{parameter}\" must be text with at least {min} characters.",
            SharedApiMessageKey.longString:                  "{index}\"{parameter}\" must be text with at most {max} characters.",
            SharedApiMessageKey.notString:                   "{index}\"{parameter}\" must be string.",
            SharedApiMessageKey.notArray:                    "{index}\"{parameter}\" must be an array.",
            SharedApiMessageKey.notDictionary:               "{index}\"{parameter}\" must be a dictionary.",
            SharedApiMessageKey.notInteger:                  "{index}\"{parameter}\" must be an integer.",
            SharedApiMessageKey.notMatchRegex:               "{index}\"{parameter}\" do not match regex: {regex}.",
            SharedApiMessageKey.emptyString:                 "{index}\"{parameter}\" must be text(s) not empty or only with blank spaces.",
            SharedApiMessageKey.emptyArray:                  "{index}\"{parameter}\" cannot be an empty array.",
            SharedApiMessageKey.positiveInteger:             "{index}\"{parameter}\" must be a positive integer greater than zero.",
            SharedApiMessageKey.nonNegativeInteger:          "{index}\"{parameter}\" must be a non-negative integer greater than or equal to zero.",
            SharedApiMessageKey.integerGreaterThanMax:       "{index}\"{parameter}\" greater than {max}.",
            SharedApiMessageKey.lengthGreaterThanMax:        "\"{parameter}\" has more than {max} items.",
            SharedApiMessageKey.invalidDateOrder:            "\"After\" must be an earlier date than \"Before\".",
            SharedApiMessageKey.invalidCpf:                  "{index}CPF is not valid by \"Receita Federal\".",
            SharedApiMessageKey.invalidCnpj:                 "{index}CNPJ is not valid by \"Receita Federal\".",
            SharedApiMessageKey.invalidTaxId:                "{index}ID must be a CPF (11 digits) or CNPJ (14 digits) formatted or unformatted.",
            SharedApiMessageKey.invalidZipCode:              "{index}Invalid ZipCode. Use the format \"@@@@@-@@@\".",
            SharedApiMessageKey.invalidStateCode:            "{index}Invalid State Code. It must have 2 digits in upper case.",
            SharedApiMessageKey.greaterThanToday:            "{index}\"{parameter}\" must be greater than today.",
            SharedApiMessageKey.greaterThanOrEqualToToday:   "{index}\"{parameter}\" must be greater than or equal to today.",
            SharedApiMessageKey.invalidHeaders:              "{index}Your CSV must have only {columns} columns {headers}.",
            SharedApiMessageKey.invalidColumn:               "{index}Missing columns.",
            SharedApiMessageKey.invalidEmail:                "Invalid Email.",
            SharedApiMessageKey.emailSent:                   "Email(s) successfully sent.",
            SharedApiMessageKey.checkApiDoc:                 "Check our API documentation at: \"https://docs.api.starkbank.com\".",
            SharedApiMessageKey.tokenWaitToRequest:          "Wait {hours} hour(s) before requesting a new {token}.",
            SharedApiMessageKey.tokenInvalid:                "Invalid token.",
            SharedApiMessageKey.permissionInvalid:           "Invalid permission.",
            SharedApiMessageKey.permissionAdmin:             "To do this action, check in Workspace Permission if you have admin rigths.",
            SharedApiMessageKey.permissionAdminOrFinancial:  "To access this information, check in Workspace Permission if you have financial or admin rights.",
            SharedApiMessageKey.deletedEntity:               "{index}This object has been deleted. You cannot access it.",
            SharedApiMessageKey.invalidDigitalSignature:     "Your digital signature is not valid."
        },
        Language.portuguese: {
            SharedApiMessageKey.usedParameter:               "Esse(a) \"{parameter}\" já foi utilizado, você deve utilizar outro.",
            SharedApiMessageKey.objectNotFound:              "{index}{object} não encontrado.",
            SharedApiMessageKey.objectNotAllowed:            "Você não pode acessar esse objeto.",
            SharedApiMessageKey.objectNotMatchKeys:          "{index}Seu objeto não tem todos as chaves requeridas.",
            SharedApiMessageKey.missingParameter:            "{index}O parametro \"{parameter}\" está faltando.",
            SharedApiMessageKey.invalidParameter:            "{index}O parametro \"{parameter}\" não é válido.",
            SharedApiMessageKey.multipleErrors:              "Sua lista possui elementos inválidos.",
            SharedApiMessageKey.shortString:                 "{index}\"{parameter}\" deve ser texto com pelo menos {min} caracteres.",
            SharedApiMessageKey.longString:                  "{index}\"{parameter}\" deve ser texto menor que {max} caracteres.",
            SharedApiMessageKey.notString:                   "{index}\"{parameter}\" deve ser texto.",
            SharedApiMessageKey.notArray:                    "{index}\"{parameter}\" deve ser uma lista.",
            SharedApiMessageKey.notDictionary:               "{index}\"{parameter}\" deve ser um dicionário.",
            SharedApiMessageKey.notInteger:                  "{index}\"{parameter}\" deve ser um inteiro.",
            SharedApiMessageKey.notMatchRegex:               "{index}\"{parameter}\" não bate com o formato regex: {regex}.",
            SharedApiMessageKey.emptyString:                 "{index}\"{parameter}\" deve(m) ser texto(s) não vazio(s) ou só espaços em branco.",
            SharedApiMessageKey.emptyArray:                  "{index}\"{parameter}\" não pode ser uma lista vazia.",
            SharedApiMessageKey.positiveInteger:             "{index}\"{parameter}\" deve ser um inteiro positivo maior do que zero.",
            SharedApiMessageKey.nonNegativeInteger:          "{index}\"{parameter}\" deve ser um inteiro não negativo maior ou igual a zero.",
            SharedApiMessageKey.integerGreaterThanMax:       "{index}\"{parameter}\" é maior que {max}.",
            SharedApiMessageKey.lengthGreaterThanMax:        "\"{parameter}\" tem mais que {max} itens.",
            SharedApiMessageKey.invalidDateOrder:            "\"After\" deve ser sempre uma data inferior a \"Before\".",
            SharedApiMessageKey.invalidCpf:                  "{index}CPF não é valido pela Receita Federal.",
            SharedApiMessageKey.invalidCnpj:                 "{index}CNPJ não é valido pela Receita Federal.",
            SharedApiMessageKey.invalidTaxId:                "{index}Use CPF (com 11 digitos) ou CNPJ (com 14 digitos) formatado ou não formatado.",
            SharedApiMessageKey.invalidZipCode:              "{index}O CEP não é valido. Formata-lo com \"@@@@@-@@@\".",
            SharedApiMessageKey.invalidStateCode:            "{index}O Código do Estado não é válido. Deve ter dois dígitos em maiusculo.",
            SharedApiMessageKey.greaterThanToday:            "{index}\"{parameter}\" deve ser maior que hoje.",
            SharedApiMessageKey.greaterThanOrEqualToToday:   "{index}\"{parameter}\" deve ser maior ou igual a hoje.",
            SharedApiMessageKey.invalidHeaders:              "{index}Seu CSV deve ter apenas {columns} colunas sendo elas {headers}.",
            SharedApiMessageKey.invalidColumn:               "{index}Falta colunas preenchidas.",
            SharedApiMessageKey.invalidEmail:                "Email inválido.",
            SharedApiMessageKey.emailSent:                   "Email(s) enviado(s) com sucesso.",
            SharedApiMessageKey.checkApiDoc:                 "Verifique nossa documentação em: \"https://docs.api.starkbank.com\".",
            SharedApiMessageKey.tokenWaitToRequest:          "Espere {hours} hora(s) antes de solicitar um novo {token}.",
            SharedApiMessageKey.tokenInvalid:                "Token inválido.",
            SharedApiMessageKey.permissionInvalid:           "Permissão inválida.",
            SharedApiMessageKey.permissionAdmin:             "Em Permissões de Workspace, verifique se você possui permissão de administrador para fazer essa ação.",
            SharedApiMessageKey.permissionAdminOrFinancial:  "Em Permissões de Workspace, verifique se você possui permissão de financeiro ou administrador para acessar essa informação.",
            SharedApiMessageKey.deletedEntity:               "{index}Esse objeto foi deletado. Você não pode mais acessá-lo.",
            SharedApiMessageKey.invalidDigitalSignature:     "Sua assinatura digital não é válida."
        }
    }
)

==> darwin-shared-v2-0.3.0.tar.gz: darwin-shared-v2-0.3.0/darwin/utils/apiMessage.py <==
# coding: utf-8

from ..utils.language import Language


class ApiMessage(object):

    def __init__(self, messages):
        self.messages = messages

    def __add__(self, other):
        messages = {}
        for key in self.messages.keys():
            value = self.messages[key]
            value.update(other.messages[key])
            messages[key] = value
        return ApiMessage(messages)

    def __radd__(self, other):
        if other == 0:
            return self
        else:
            return self.__add__(other)

    def __str__(self):
        return self.messages.__str__()

    def get(self, key, language, **data):
        data["index"] = "Element %s: " % data["index"] if "index" in data else ""
        return self.messages.get(language, {}).get(key, "NULL").format(**data)


class SharedApiCode:

    missingAuthentication = "missingAuthentication"
    invalidQueryString = "invalidQueryString"
    invalidAction = "invalidAction"
    invalidIds = "invalidIds"
    invalidJson = "invalidJson"
    invalidToken = "invalidToken"
    invalidExternalId = "invalidExternalId"
    invalidAmount = "invalidAmount"
    invalidDate = "invalidDate"
    invalidPermission = "invalidPermission"
    invalidTaxId = "invalidTaxId"
    invalidName = "invalidName"
    invalidEmail = "invalidEmail"
    invalidPhone = "invalidPhone"
    invalidAddress = "invalidAddress"
    invalidStreetLine1 = "invalidStreetLine1"
    invalidStreetLine2 = "invalidStreetLine2"
    invalidDistrict = "invalidDistrict"
    invalidCity = "invalidCity"
    invalidStateCode = "invalidStateCode"
    invalidZipCode = "invalidZipCode"
    invalidTags = "invalidTags"
    invalidCsv = "invalidCsv"
    invalidStatus = "invalidStatus"
    invalidDescription = "invalidDescription"
    invalidDigitalSignature = "invalidDigitalSignature"
    invalidLimit = "invalidLimit"
    invalidSort = "invalidSort"
    invalidDateTime = "invalidDateTime"


class SharedApiMessageKey:

    missingAuthentication = "missingAuthentication"
    usedParameter = "usedParameter"
    objectNotFound = "objectNotFound"
    objectNotAllowed = "objectNotAllowed"
    objectNotMatchKeys = "objectNotMatchKeys"
    missingParameter = "missingParameter"
    invalidParameter = "invalidParameter"
    invalidParameters = "invalidParameters"
    repeatedParameters = "repeatedParameters"
    multipleErrors = "multipleErrors"
    multipleQueryErrors = "multipleQueryErrors"
    emptyString = "emptyString"
    shortString = "shortString"
    longString = "longString"
    notString = "notString"
    notArray = "notArray"
    notDictionary = "notDictionary"
    notInteger = "notInteger"
    notMatchRegex = "notMatchRegex"
    emptyArray = "emptyArray"
    positiveInteger = "positiveInteger"
    nonNegativeInteger = "nonNegativeInteger"
    integerGreaterThanMax = "integerGreaterThanMax"
    lengthGreaterThanMax = "lengthGreaterThanMax"
    invalidLimit = "invalidLimit"
    invalidDateOrder = "invalidDateOrder"
    invalidCpf = "invalidCpf"
    invalidCnpj = "invalidCnpj"
    invalidTaxId = "invalidTaxId"
    invalidZipCode = "invalidZipCode"
    invalidStateCode = "invalidStateCode"
    greaterThanToday = "greaterThanToday"
    greaterThanOrEqualToToday = "greaterThanOrEqualToToday"
    invalidHeaders = "invalidHeaders"
    invalidColumn = "invalidColumn"
    invalidEmail = "invalidEmail"
    emailSent = "emailSent"
    checkApiDoc = "checkApiDoc"
    tokenWaitToRequest = "tokenWaitToRequest"
    tokenInvalid = "tokenInvalid"
    permissionInvalid = "permissionInvalid"
    permissionAdmin = "permissionAdmin"
    permissionAdminOrFinancial = "permissionAdminOrFinancial"
    deletedEntity = "deletedEntity"
    invalidDigitalSignature = "notMatchSignature"
    invalidSort = "invalidSort"
    badIdsFormatting = "badIdsFormatting"
    invalidDateTime = "invalidDateTime"
    invalidIdType = "invalidIdType"


SharedApiMessage = ApiMessage(
    messages={
        Language.english: {
            SharedApiMessageKey.missingAuthentication:       "This endpoint requires authentication",
            SharedApiMessageKey.usedParameter:               "The parameter \"{parameter}\" has already been used, you should use another one.",
            SharedApiMessageKey.objectNotFound:              "{index}{object} not found.",
            SharedApiMessageKey.objectNotAllowed:            "You are not allowed to access this object.",
            SharedApiMessageKey.objectNotMatchKeys:          "{index}Your object does not match all required keys.",
            SharedApiMessageKey.missingParameter:            "{index}Missing \"{parameter}\" parameter.",
            SharedApiMessageKey.invalidParameter:            "{index}\"{parameter}\" is not a valid parameter.",
            SharedApiMessageKey.invalidParameters:           "{index}[{parameters}] are not valid parameters.",
            SharedApiMessageKey.repeatedParameters:          "{index}[{parameters}] parameters have been repeated.",
            SharedApiMessageKey.multipleErrors:              "Your array contains invalid elements.",
            SharedApiMessageKey.multipleQueryErrors:         "Your query string contains invalid parameters.",
            SharedApiMessageKey.shortString:                 "{index}\"{parameter}\" must be a text with at least {min} characters.",
            SharedApiMessageKey.longString:                  "{index}\"{parameter}\" must be a text with at most {max} characters.",
            SharedApiMessageKey.notString:                   "{index}\"{parameter}\" must be a string.",
            SharedApiMessageKey.notArray:                    "{index}\"{parameter}\" must be an array.",
            SharedApiMessageKey.notDictionary:               "{index}\"{parameter}\" must be a dictionary.",
            SharedApiMessageKey.notInteger:                  "{index}\"{parameter}\" must be an integer.",
            SharedApiMessageKey.notMatchRegex:               "{index}\"{parameter}\" does not match regex: {regex}.",
            SharedApiMessageKey.emptyString:                 "{index}\"{parameter}\" cannot be an empty text.",
            SharedApiMessageKey.emptyArray:                  "{index}\"{parameter}\" cannot be an empty array.",
            SharedApiMessageKey.positiveInteger:             "{index}\"{parameter}\" must be a positive integer greater than zero.",
            SharedApiMessageKey.nonNegativeInteger:          "{index}\"{parameter}\" must be a non-negative integer greater than or equal to zero.",
            SharedApiMessageKey.integerGreaterThanMax:       "{index}\"{parameter}\" greater than {max}.",
            SharedApiMessageKey.lengthGreaterThanMax:        "{index}\"{parameter}\" has more than {max} items.",
            SharedApiMessageKey.invalidLimit:                "\"limit\" must be an integer between 1 and {maxLimit}.",
            SharedApiMessageKey.invalidDateOrder:            "\"after\" must be an earlier date than \"before\".",
            SharedApiMessageKey.invalidCpf:                  "{index}CPF is not valid by \"Receita Federal\".",
            SharedApiMessageKey.invalidCnpj:                 "{index}CNPJ is not valid by \"Receita Federal\".",
            SharedApiMessageKey.invalidTaxId:                "{index}taxId must be a CPF (11 digits) or CNPJ (14 digits) either formatted or unformatted.",
            SharedApiMessageKey.invalidZipCode:              "{index}Invalid ZipCode. Use the format \"@@@@@-@@@\".",
            SharedApiMessageKey.invalidStateCode:            "{index}Invalid State Code. It must have 2 letters in upper case.",
            SharedApiMessageKey.greaterThanToday:            "{index}\"{parameter}\" must be greater than today.",
            SharedApiMessageKey.greaterThanOrEqualToToday:   "{index}\"{parameter}\" must be greater than or equal to today.",
            SharedApiMessageKey.invalidHeaders:              "{index}Your CSV must have only {columns} columns {headers}.",
            SharedApiMessageKey.invalidColumn:               "{index}Missing columns.",
            SharedApiMessageKey.invalidEmail:                "Invalid e-mail.",
            SharedApiMessageKey.emailSent:                   "e-mail(s) successfully sent.",
            SharedApiMessageKey.checkApiDoc:                 "Check our API documentation at: \"https://docs.api.starkbank.com\".",
            SharedApiMessageKey.tokenWaitToRequest:          "Wait {hours} hour(s) before requesting a new {token}.",
            SharedApiMessageKey.tokenInvalid:                "Invalid token.",
            SharedApiMessageKey.permissionInvalid:           "Invalid permission.",
            SharedApiMessageKey.permissionAdmin:             "To perform this action, check in Workspace Permissions if you have admin rigths.",
            SharedApiMessageKey.permissionAdminOrFinancial:  "To access this information, check in Workspace Permissions if you have financial or admin rights.",
            SharedApiMessageKey.deletedEntity:               "{index}This object has been deleted. You cannot access it.",
            SharedApiMessageKey.invalidDigitalSignature:     "Your digital signature is not valid.",
            SharedApiMessageKey.invalidSort:                 "Sort parameter must be in [{sorts}]",
            SharedApiMessageKey.badIdsFormatting:            "{idsParameterName} must be a list of strings convertible to integers",
            SharedApiMessageKey.invalidDateTime:             "{parameter} is invalid. Please define it in one of the following formats: {formats}",
            SharedApiMessageKey.invalidIdType:               "{parameterName} must be convertible to an integer",
        },
        Language.portuguese: {
            SharedApiMessageKey.missingAuthentication:       "Este endpoint requer autenticação",
            SharedApiMessageKey.usedParameter:               "Esse(a) \"{parameter}\" já foi utilizado, você deve utilizar outro.",
            SharedApiMessageKey.objectNotFound:              "{index}{object} não encontrado.",
            SharedApiMessageKey.objectNotAllowed:            "Você não pode acessar esse objeto.",
            SharedApiMessageKey.objectNotMatchKeys:          "{index}Seu objeto não tem todos as chaves requeridas.",
            SharedApiMessageKey.missingParameter:            "{index}O parâmetro \"{parameter}\" está faltando.",
            SharedApiMessageKey.invalidParameter:            "{index}O parâmetro \"{parameter}\" não é válido.",
            SharedApiMessageKey.invalidParameters:           "{index}Os parâmetros [{parameters}] não são válidos.",
            SharedApiMessageKey.repeatedParameters:          "{index}Os parâmetros [{parameters}] foram repetidos.",
            SharedApiMessageKey.multipleErrors:              "Sua lista possui elementos inválidos.",
            SharedApiMessageKey.multipleQueryErrors:         "Sua query string possui parâmetros inválidos.",
            SharedApiMessageKey.shortString:                 "{index}\"{parameter}\" deve ser texto com pelo menos {min} caracteres.",
            SharedApiMessageKey.longString:                  "{index}\"{parameter}\" deve ser texto menor que {max} caracteres.",
            SharedApiMessageKey.notString:                   "{index}\"{parameter}\" deve ser texto.",
            SharedApiMessageKey.notArray:                    "{index}\"{parameter}\" deve ser uma lista.",
            SharedApiMessageKey.notDictionary:               "{index}\"{parameter}\" deve ser um dicionário.",
            SharedApiMessageKey.notInteger:                  "{index}\"{parameter}\" deve ser um inteiro.",
            SharedApiMessageKey.notMatchRegex:               "{index}\"{parameter}\" não bate com o formato regex: {regex}.",
            SharedApiMessageKey.emptyString:                 "{index}\"{parameter}\" deve(m) ser texto(s) não vazio(s) ou só espaços em branco.",
            SharedApiMessageKey.emptyArray:                  "{index}\"{parameter}\" não pode ser uma lista vazia.",
            SharedApiMessageKey.positiveInteger:             "{index}\"{parameter}\" deve ser um inteiro positivo maior do que zero.",
            SharedApiMessageKey.nonNegativeInteger:          "{index}\"{parameter}\" deve ser um inteiro não negativo maior ou igual a zero.",
            SharedApiMessageKey.integerGreaterThanMax:       "{index}\"{parameter}\" é maior que {max}.",
            SharedApiMessageKey.lengthGreaterThanMax:        "{index}\"{parameter}\" tem mais que {max} itens.",
            SharedApiMessageKey.invalidLimit:                "\"limit\" deve ser um inteiro entre 1 e {maxLimit}.",
            SharedApiMessageKey.invalidDateOrder:            "\"After\" deve ser sempre uma data inferior a \"Before\".",
            SharedApiMessageKey.invalidCpf:                  "{index}CPF não é valido pela Receita Federal.",
            SharedApiMessageKey.invalidCnpj:                 "{index}CNPJ não é valido pela Receita Federal.",
            SharedApiMessageKey.invalidTaxId:                "{index}Use CPF (com 11 digitos) ou CNPJ (com 14 digitos) formatado ou não formatado.",
            SharedApiMessageKey.invalidZipCode:              "{index}O CEP não é valido. Formata-lo com \"@@@@@-@@@\".",
            SharedApiMessageKey.invalidStateCode:            "{index}O Código do Estado não é válido. Deve ter dois dígitos em maiusculo.",
            SharedApiMessageKey.greaterThanToday:            "{index}\"{parameter}\" deve ser maior que hoje.",
            SharedApiMessageKey.greaterThanOrEqualToToday:   "{index}\"{parameter}\" deve ser maior ou igual a hoje.",
            SharedApiMessageKey.invalidHeaders:              "{index}Seu CSV deve ter apenas {columns} colunas sendo elas {headers}.",
            SharedApiMessageKey.invalidColumn:               "{index}Falta colunas preenchidas.",
            SharedApiMessageKey.invalidEmail:                "Email inválido.",
            SharedApiMessageKey.emailSent:                   "Email(s) enviado(s) com sucesso.",
            SharedApiMessageKey.checkApiDoc:                 "Verifique nossa documentação em: \"https://docs.api.starkbank.com\".",
            SharedApiMessageKey.tokenWaitToRequest:          "Espere {hours} hora(s) antes de solicitar um novo {token}.",
            SharedApiMessageKey.tokenInvalid:                "Token inválido.",
            SharedApiMessageKey.permissionInvalid:           "Permissão inválida.",
            SharedApiMessageKey.permissionAdmin:             "Em Permissões de Workspace, verifique se você possui permissão de administrador para fazer essa ação.",
            SharedApiMessageKey.permissionAdminOrFinancial:  "Em Permissões de Workspace, verifique se você possui permissão de financeiro ou administrador para acessar essa informação.",
            SharedApiMessageKey.deletedEntity:               "{index}Esse objeto foi deletado. Você não pode mais acessá-lo.",
            SharedApiMessageKey.invalidDigitalSignature:     "Sua assinatura digital não é válida.",
            SharedApiMessageKey.invalidSort:                 "Parâmetro de ordenação deve estar contido em [{sorts}]",
            SharedApiMessageKey.badIdsFormatting:            "{idsParameterName} deve ser uma lista de strings conversíveis para inteiros",
            SharedApiMessageKey.invalidDateTime:             "{parameter} é inválido; por favor o defina em um dos seguintes formatos: {formats}",
            SharedApiMessageKey.invalidIdType:               "{parameterName} deve ser conversível para um inteiro",
        }
    }
)
